@@ -19,7 +19,7 @@
  */
 package mediathek.gui.dialogEinstellungen;
 
-import java.awt.Component;
+import com.jidesoft.utils.SystemInfo;
 import java.awt.Cursor;
 import java.awt.FileDialog;
 import java.awt.event.ActionEvent;
@@ -29,56 +29,79 @@ import java.awt.event.MouseListener;
 import java.io.File;
 import javax.swing.JDialog;
 import javax.swing.JFileChooser;
+import javax.swing.JFrame;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
-import javax.swing.event.ListSelectionEvent;
-
-import com.jidesoft.utils.SystemInfo;
-import mediathek.controller.filmeLaden.importieren.DatenUrlFilmliste;
-import mediathek.controller.filmeLaden.importieren.FilmlistenSuchen;
-import mediathek.daten.DDaten;
+import mediathek.controller.Log;
 import mediathek.daten.Daten;
 import mediathek.gui.PanelVorlage;
 import mediathek.res.GetIcon;
 import mediathek.tool.GuiFunktionen;
-import mediathek.tool.GuiKonstanten;
 import mediathek.tool.Konstanten;
 import mediathek.tool.ListenerMediathekView;
-import mediathek.tool.Log;
+import mediathek.tool.MVColor;
+import mediathek.tool.MVConfig;
 import mediathek.tool.TModel;
+import msearch.filmeLaden.DatenFilmlisteUrl;
 
 public class PanelFilmlisteLaden extends PanelVorlage {
 
     private JDialog dialog = null;
 
-    public PanelFilmlisteLaden(DDaten d, Component parentComponent, JDialog ddialog) {
+    public PanelFilmlisteLaden(Daten d, JFrame parentComponent, JDialog ddialog) {
         super(d, parentComponent);
         dialog = ddialog;
         initComponents();
         init();
     }
 
-    public PanelFilmlisteLaden(DDaten d, Component parentComponent) {
+    public PanelFilmlisteLaden(Daten d, JFrame parentComponent) {
         super(d, parentComponent);
         initComponents();
         init();
     }
 
     private void init() {
-        jButtonUpdate.setIcon(GetIcon.getIcon("view-refresh_16.png"));
-        jButtonDateiAuswaehlen.setIcon(GetIcon.getIcon("fileopen_16.png"));
+        jButtonAkualisieren.setIcon(GetIcon.getProgramIcon("view-refresh_16.png"));
+        jButtonDateiAuswaehlen.setIcon(GetIcon.getProgramIcon("fileopen_16.png"));
         initRadio();
         tabelleLaden();
-        jButtonUpdate.addActionListener(new BeobSuchen());
+        jButtonAkualisieren.addActionListener(new ActionListener() {
+
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                listeFilmlistenSuchen();
+            }
+        });
         jButtonDateiAuswaehlen.addActionListener(new BeobPfad());
         jButtonFilmeLaden.addActionListener(new ActionListener() {
             @Override
             public void actionPerformed(ActionEvent e) {
-                Daten.filmeLaden.importFilmliste(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
+                if (jCheckBoxUpdate.isSelected()) {
+                    Daten.filmeLaden.updateFilmliste(jTextFieldUrl.getText());
+                } else {
+                    Daten.filmeLaden.importFilmliste(jTextFieldUrl.getText());
+                }
             }
         });
         jRadioButtonUpdateAus.addActionListener(new BeobOption());
         jRadioButtonAuto.addActionListener(new BeobOption());
+        jRadioButtonAkt.addActionListener(new ActionListener() {
+
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                jCheckBoxUpdate.setSelected(jRadioButtonDiff.isSelected());
+                tabelleLaden();
+            }
+        });
+        jRadioButtonDiff.addActionListener(new ActionListener() {
+
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                jCheckBoxUpdate.setSelected(jRadioButtonDiff.isSelected());
+                tabelleLaden();
+            }
+        });
         //jTable1.getSelectionModel().addListSelectionListener(new BeobachterTableSelect());
         jTable1.addMouseListener(new BeobachterTableSelect());
         jTextFieldUrl.getDocument().addDocumentListener(new BeobDateiUrl());
@@ -97,34 +120,40 @@ public class PanelFilmlisteLaden extends PanelVorlage {
     }
 
     private void initRadio() {
-        if (GuiFunktionen.getImportArtFilme() == GuiKonstanten.UPDATE_FILME_AUS) {
+        if (GuiFunktionen.getImportArtFilme() == Konstanten.UPDATE_FILME_AUS) {
             jRadioButtonUpdateAus.setSelected(true);
         } else {
             jRadioButtonAuto.setSelected(true);
         }
-        jTextFieldUrl.setText(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
+        jTextFieldUrl.setText(Daten.mVConfig.get(MVConfig.SYSTEM_IMPORT_URL_MANUELL));
         setPanelTabelle(jRadioButtonUpdateAus.isSelected());
     }
 
-    private void updateSuchen() {
+    private void listeFilmlistenSuchen() {
         this.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-        DDaten.filmeLaden.getDownloadUrlsFilmlisten(true); // Liste neu laden und eine URL auswählen
+        if (jRadioButtonAkt.isSelected()) {
+            Daten.filmeLaden.updateDownloadUrlsFilmlisten(true, false);
+        } else /*diff*/ {
+            Daten.filmeLaden.updateDownloadUrlsFilmlisten(false, true);
+        }
         stopBeob = true;
-        jTextFieldUrl.setText(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
         tabelleLaden();
         stopBeob = false;
         this.setCursor(Cursor.getDefaultCursor());
     }
 
     private void tabelleLaden() {
-        TModel model = new TModel(DDaten.filmeLaden.getDownloadUrlsFilmlisten(false).getTableObjectData(), FilmlistenSuchen.FILM_UPDATE_SERVER_COLUMN_NAMES_ANZEIGE);
-        jTable1.setModel(model);
+        if (jRadioButtonAkt.isSelected()) {
+            jTable1.setModel(new TModel(Daten.filmeLaden.getDownloadUrlsFilmlisten_akt().getTableObjectData(), DatenFilmlisteUrl.FILM_UPDATE_SERVER_COLUMN_NAMES_ANZEIGE));
+        } else /*diff*/ {
+            jTable1.setModel(new TModel(Daten.filmeLaden.getDownloadUrlsFilmlisten_diff().getTableObjectData(), DatenFilmlisteUrl.FILM_UPDATE_SERVER_COLUMN_NAMES_ANZEIGE));
+        }
         for (int i = 0; i < jTable1.getColumnCount(); ++i) {
-            if (i == FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR) {
+            if (i == DatenFilmlisteUrl.FILM_UPDATE_SERVER_URL_NR) {
                 jTable1.getColumnModel().getColumn(i).setMinWidth(10);
                 jTable1.getColumnModel().getColumn(i).setMaxWidth(3000);
-                jTable1.getColumnModel().getColumn(i).setPreferredWidth(350);
-            } else if (!Daten.debug && i == FilmlistenSuchen.FILM_UPDATE_SERVER_PRIO_NR) {
+                jTable1.getColumnModel().getColumn(i).setPreferredWidth(400);
+            } else if (!Daten.debug && (i == DatenFilmlisteUrl.FILM_UPDATE_SERVER_PRIO_NR || i == DatenFilmlisteUrl.FILM_UPDATE_SERVER_ART_NR)) {
                 jTable1.getColumnModel().getColumn(i).setMinWidth(0);
                 jTable1.getColumnModel().getColumn(i).setMaxWidth(0);
                 jTable1.getColumnModel().getColumn(i).setPreferredWidth(0);
@@ -134,24 +163,40 @@ public class PanelFilmlisteLaden extends PanelVorlage {
                 jTable1.getColumnModel().getColumn(i).setPreferredWidth(100);
             }
         }
+        if (jRadioButtonDiff.isSelected() || jRadioButtonAkt.isSelected()) {
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_DATUM_NR)).setMinWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_DATUM_NR)).setPreferredWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_DATUM_NR)).setMaxWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_ZEIT_NR)).setMinWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_ZEIT_NR)).setPreferredWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_ZEIT_NR)).setMaxWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_PRIO_NR)).setMinWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_PRIO_NR)).setPreferredWidth(0);
+            jTable1.getColumnModel().getColumn(jTable1.convertColumnIndexToView(DatenFilmlisteUrl.FILM_UPDATE_SERVER_PRIO_NR)).setMaxWidth(0);
+        }
     }
 
     private void table1Select(boolean doppel) {
         stopBeob = true;
-        DatenUrlFilmliste datenUrlFilmliste = null;
+        DatenFilmlisteUrl datenUrlFilmliste = null;
         int selectedTableRow = jTable1.getSelectedRow();
         if (selectedTableRow >= 0) {
-            datenUrlFilmliste = Daten.filmeLaden.getDownloadUrlsFilmlisten(false).getDatenUrlFilmliste(jTable1.getModel().getValueAt(jTable1.convertRowIndexToModel(selectedTableRow),
-                    FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR).toString());
+            String url = jTable1.getModel().getValueAt(jTable1.convertRowIndexToModel(selectedTableRow), DatenFilmlisteUrl.FILM_UPDATE_SERVER_URL_NR).toString();
+            if (jRadioButtonAkt.isSelected()) {
+                datenUrlFilmliste = Daten.filmeLaden.getDownloadUrlsFilmlisten_akt().getDatenUrlFilmliste(url);
+            } else /*diff*/ {
+                datenUrlFilmliste = Daten.filmeLaden.getDownloadUrlsFilmlisten_diff().getDatenUrlFilmliste(url);
+            }
         }
         if (datenUrlFilmliste != null) {
-            //jRadioButtonUpdateAus.setSelected(true);
-            //daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(Konstanten.UPDATE_FILME_AUS);
-            jTextFieldUrl.setText(datenUrlFilmliste.arr[FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR]);
-            Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR] = datenUrlFilmliste.arr[FilmlistenSuchen.FILM_UPDATE_SERVER_URL_NR];
+            jTextFieldUrl.setText(datenUrlFilmliste.arr[DatenFilmlisteUrl.FILM_UPDATE_SERVER_URL_NR]);
             if (doppel) {
                 // dann wars ein Doppelklick, gleich laden
-                Daten.filmeLaden.importFilmliste(Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR]);
+                if (jCheckBoxUpdate.isSelected()) {
+                    Daten.filmeLaden.updateFilmliste(jTextFieldUrl.getText());
+                } else {
+                    Daten.filmeLaden.importFilmliste(jTextFieldUrl.getText());
+                }
             }
         }
         stopBeob = false;
@@ -161,11 +206,13 @@ public class PanelFilmlisteLaden extends PanelVorlage {
     }
 
     private void setPanelTabelle(boolean manuell) {
-        jButtonUpdate.setEnabled(manuell);
-        jTextFieldUrl.setEnabled(manuell);
-        jTable1.setEnabled(manuell);
-        jButtonDateiAuswaehlen.setEnabled(manuell);
-        jButtonFilmeLaden.setEnabled(manuell);
+        if (manuell) {
+            jTextAreaManuell.setBackground(MVColor.FILMLISTE_LADEN_AKTIV.color);
+            jTextAreaAuto.setBackground(null);
+        } else {
+            jTextAreaManuell.setBackground(null);
+            jTextAreaAuto.setBackground(MVColor.FILMLISTE_LADEN_AKTIV.color);
+        }
     }
 
     /** This method is called from within the constructor to
@@ -177,31 +224,35 @@ public class PanelFilmlisteLaden extends PanelVorlage {
     private void initComponents() {
 
         javax.swing.ButtonGroup buttonGroup1 = new javax.swing.ButtonGroup();
+        javax.swing.ButtonGroup buttonGroup2 = new javax.swing.ButtonGroup();
         javax.swing.JPanel jPanel3 = new javax.swing.JPanel();
         javax.swing.JScrollPane jScrollPane2 = new javax.swing.JScrollPane();
-        javax.swing.JTextArea jTextArea1 = new javax.swing.JTextArea();
+        jTextAreaAuto = new javax.swing.JTextArea();
         javax.swing.JPanel jPanel2 = new javax.swing.JPanel();
         javax.swing.JScrollPane jScrollPane1 = new javax.swing.JScrollPane();
         jTable1 = new javax.swing.JTable();
         javax.swing.JLabel jLabel2 = new javax.swing.JLabel();
-        jButtonUpdate = new javax.swing.JButton();
+        jButtonAkualisieren = new javax.swing.JButton();
         javax.swing.JLabel jLabel1 = new javax.swing.JLabel();
         jTextFieldUrl = new javax.swing.JTextField();
         jButtonDateiAuswaehlen = new javax.swing.JButton();
         jButtonFilmeLaden = new javax.swing.JButton();
         javax.swing.JScrollPane jScrollPane3 = new javax.swing.JScrollPane();
-        javax.swing.JTextArea jTextArea2 = new javax.swing.JTextArea();
+        jTextAreaManuell = new javax.swing.JTextArea();
+        jCheckBoxUpdate = new javax.swing.JCheckBox();
+        jRadioButtonAkt = new javax.swing.JRadioButton();
+        jRadioButtonDiff = new javax.swing.JRadioButton();
         jRadioButtonAuto = new javax.swing.JRadioButton();
         jRadioButtonUpdateAus = new javax.swing.JRadioButton();
 
         jPanel3.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 255)), "Die Filmliste automatisch laden"));
 
-        jTextArea1.setEditable(false);
-        jTextArea1.setColumns(20);
-        jTextArea1.setRows(3);
-        jTextArea1.setText("Die Filmliste wird beim Programmstart automatisch geladen (wenn sie\nälter als 3h ist). Zusätzlich kann sie über den Button \"Neue Filmliste laden\"\ngeladen werden.");
-        jTextArea1.setMargin(new java.awt.Insets(4, 4, 4, 4));
-        jScrollPane2.setViewportView(jTextArea1);
+        jTextAreaAuto.setEditable(false);
+        jTextAreaAuto.setColumns(20);
+        jTextAreaAuto.setRows(4);
+        jTextAreaAuto.setText("Die Filmliste wird beim Programmstart automatisch geladen (wenn sie\nälter als 3h ist). Zusätzlich kann sie über den Button \"Neue Filmliste laden\"\naktualisiert werden. Zum Update werden dann nur noch die Differenzlisten geladen (enthalten\nnur die neuen Filme).");
+        jTextAreaAuto.setMargin(new java.awt.Insets(4, 4, 4, 4));
+        jScrollPane2.setViewportView(jTextAreaAuto);
 
         javax.swing.GroupLayout jPanel3Layout = new javax.swing.GroupLayout(jPanel3);
         jPanel3.setLayout(jPanel3Layout);
@@ -222,37 +273,35 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         jPanel2.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 255)), "Filmliste nur manuell laden"));
 
         jTable1.setAutoCreateRowSorter(true);
-        jTable1.setBorder(javax.swing.BorderFactory.createEtchedBorder());
-        jTable1.setModel(new javax.swing.table.DefaultTableModel(
-            new Object [][] {
-                {null, null, null, null},
-                {null, null, null, null},
-                {null, null, null, null},
-                {null, null, null, null}
-            },
-            new String [] {
-                "Title 1", "Title 2", "Title 3", "Title 4"
-            }
-        ));
+        jTable1.setModel(new TModel());
         jTable1.setAutoResizeMode(javax.swing.JTable.AUTO_RESIZE_OFF);
         jScrollPane1.setViewportView(jTable1);
 
-        jLabel2.setText("Liste der Downloadserver (URL's) aktualisieren:");
+        jLabel2.setText("Liste aktualisieren:");
 
-        jButtonUpdate.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/view-refresh_16.png"))); // NOI18N
+        jButtonAkualisieren.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/programm/view-refresh_16.png"))); // NOI18N
 
         jLabel1.setText("URL/Datei:");
 
-        jButtonDateiAuswaehlen.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/fileopen_16.png"))); // NOI18N
+        jButtonDateiAuswaehlen.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/programm/fileopen_16.png"))); // NOI18N
 
         jButtonFilmeLaden.setText("Filme jetzt laden");
 
-        jTextArea2.setEditable(false);
-        jTextArea2.setColumns(20);
-        jTextArea2.setRows(3);
-        jTextArea2.setText("Die Filmliste wird nur manuell über den Button \"Neue Filmliste laden\"\ngeladen. Es wird dann dieser Dialog angezeigt und es kann eine URL/Datei zum\nLaden ausgewählt werden.");
-        jTextArea2.setMargin(new java.awt.Insets(4, 4, 4, 4));
-        jScrollPane3.setViewportView(jTextArea2);
+        jTextAreaManuell.setEditable(false);
+        jTextAreaManuell.setColumns(20);
+        jTextAreaManuell.setRows(4);
+        jTextAreaManuell.setText("Die Filmliste wird nur manuell über den Button \"Neue Filmliste laden\"\ngeladen. Es wird dann dieser Dialog angezeigt und es kann eine URL/Datei zum\nLaden ausgewählt werden. Ist die Filmliste nicht älter als 1 Tag,\nreicht eine Differenzliste (enthält nur die neuen Filme).");
+        jTextAreaManuell.setMargin(new java.awt.Insets(4, 4, 4, 4));
+        jScrollPane3.setViewportView(jTextAreaManuell);
+
+        jCheckBoxUpdate.setText("alte Filmliste nicht löschen, nur erweitern");
+
+        buttonGroup2.add(jRadioButtonAkt);
+        jRadioButtonAkt.setSelected(true);
+        jRadioButtonAkt.setText("aktuelle komplette Listen");
+
+        buttonGroup2.add(jRadioButtonDiff);
+        jRadioButtonDiff.setText("Differenzlisten");
 
         javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
         jPanel2.setLayout(jPanel2Layout);
@@ -261,41 +310,49 @@ public class PanelFilmlisteLaden extends PanelVorlage {
             .addGroup(jPanel2Layout.createSequentialGroup()
                 .addContainerGap()
                 .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                    .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 599, Short.MAX_VALUE)
+                    .addComponent(jScrollPane1)
                     .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel2Layout.createSequentialGroup()
                         .addComponent(jLabel1)
                         .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                         .addComponent(jTextFieldUrl)
                         .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                         .addComponent(jButtonDateiAuswaehlen))
+                    .addComponent(jScrollPane3)
                     .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel2Layout.createSequentialGroup()
-                        .addGap(0, 0, Short.MAX_VALUE)
-                        .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
-                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel2Layout.createSequentialGroup()
-                                .addComponent(jLabel2)
-                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
-                                .addComponent(jButtonUpdate))
-                            .addComponent(jButtonFilmeLaden, javax.swing.GroupLayout.Alignment.TRAILING)))
-                    .addComponent(jScrollPane3))
+                        .addComponent(jCheckBoxUpdate)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                        .addComponent(jButtonFilmeLaden))
+                    .addGroup(jPanel2Layout.createSequentialGroup()
+                        .addComponent(jRadioButtonAkt)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
+                        .addComponent(jRadioButtonDiff)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 172, Short.MAX_VALUE)
+                        .addComponent(jLabel2)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(jButtonAkualisieren)))
                 .addContainerGap())
         );
         jPanel2Layout.setVerticalGroup(
             jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
             .addGroup(jPanel2Layout.createSequentialGroup()
                 .addComponent(jScrollPane3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
-                .addGap(18, 18, 18)
-                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.CENTER)
-                    .addComponent(jLabel2)
-                    .addComponent(jButtonUpdate))
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
-                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 183, Short.MAX_VALUE)
+                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.CENTER)
+                    .addComponent(jRadioButtonAkt)
+                    .addComponent(jRadioButtonDiff)
+                    .addComponent(jLabel2)
+                    .addComponent(jButtonAkualisieren))
+                .addGap(9, 9, 9)
+                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 258, Short.MAX_VALUE)
                 .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                 .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                     .addComponent(jTextFieldUrl, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                     .addComponent(jLabel1)
                     .addComponent(jButtonDateiAuswaehlen))
                 .addGap(18, 18, 18)
-                .addComponent(jButtonFilmeLaden)
+                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
+                    .addComponent(jButtonFilmeLaden)
+                    .addComponent(jCheckBoxUpdate))
                 .addContainerGap())
         );
 
@@ -337,32 +394,29 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         );
     }// </editor-fold>//GEN-END:initComponents
     // Variables declaration - do not modify//GEN-BEGIN:variables
+    private javax.swing.JButton jButtonAkualisieren;
     private javax.swing.JButton jButtonDateiAuswaehlen;
     private javax.swing.JButton jButtonFilmeLaden;
-    private javax.swing.JButton jButtonUpdate;
+    private javax.swing.JCheckBox jCheckBoxUpdate;
+    private javax.swing.JRadioButton jRadioButtonAkt;
     private javax.swing.JRadioButton jRadioButtonAuto;
+    private javax.swing.JRadioButton jRadioButtonDiff;
     private javax.swing.JRadioButton jRadioButtonUpdateAus;
     private javax.swing.JTable jTable1;
+    private javax.swing.JTextArea jTextAreaAuto;
+    private javax.swing.JTextArea jTextAreaManuell;
     private javax.swing.JTextField jTextFieldUrl;
     // End of variables declaration//GEN-END:variables
 
-    private class BeobSuchen implements ActionListener {
-
-        @Override
-        public void actionPerformed(ActionEvent e) {
-            updateSuchen();
-        }
-    }
-
     private class BeobOption implements ActionListener {
 
         @Override
         public void actionPerformed(ActionEvent e) {
             if (!stopBeob) {
                 if (jRadioButtonUpdateAus.isSelected()) {
-                    Daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(GuiKonstanten.UPDATE_FILME_AUS);
+                    Daten.mVConfig.add(MVConfig.SYSTEM_IMPORT_ART_FILME, String.valueOf(Konstanten.UPDATE_FILME_AUS));
                 } else {
-                    Daten.system[Konstanten.SYSTEM_IMPORT_ART_FILME_NR] = String.valueOf(GuiKonstanten.UPDATE_FILME_AUTO);
+                    Daten.mVConfig.add(MVConfig.SYSTEM_IMPORT_ART_FILME, String.valueOf(Konstanten.UPDATE_FILME_AUTO));
                 }                // den Dialog gibts 2x
                 ListenerMediathekView.notify(ListenerMediathekView.EREIGNIS_ART_IMPORT_FILMLISTE, this.getClass().getSimpleName());
             }
@@ -371,14 +425,6 @@ public class PanelFilmlisteLaden extends PanelVorlage {
 
     private class BeobachterTableSelect implements MouseListener {
 
-        public void valueChanged(ListSelectionEvent event) {
-            if (!stopBeob) {
-                if (!event.getValueIsAdjusting()) {
-                    table1Select(false);
-                }
-            }
-        }
-
         @Override
         public void mouseClicked(MouseEvent e) {
             if (e.getClickCount() == 2) {
@@ -411,7 +457,7 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         public void actionPerformed(ActionEvent e) {
             //we can use native chooser on Mac...
             if (SystemInfo.isMacOSX()) {
-                FileDialog chooser = new FileDialog(ddaten.mediathekGui, "Filmliste laden");
+                FileDialog chooser = new FileDialog(daten.mediathekGui, "Filmliste laden");
                 chooser.setMode(FileDialog.LOAD);
                 chooser.setVisible(true);
                 if (chooser.getFile() != null) {
@@ -419,7 +465,7 @@ public class PanelFilmlisteLaden extends PanelVorlage {
                         File destination = new File(chooser.getDirectory() + chooser.getFile());
                         jTextFieldUrl.setText(destination.getAbsolutePath());
                     } catch (Exception ex) {
-                        Log.fehlerMeldung(102036579, Log.FEHLER_ART_PROG, "PanelImportFilme.BeobPfad", ex);
+                        Log.fehlerMeldung(102036579, "PanelImportFilme.BeobPfad", ex);
                     }
                 }
             } else {
@@ -435,7 +481,7 @@ public class PanelFilmlisteLaden extends PanelVorlage {
                     try {
                         jTextFieldUrl.setText(chooser.getSelectedFile().getAbsolutePath());
                     } catch (Exception ex) {
-                        Log.fehlerMeldung(733025319, Log.FEHLER_ART_PROG, "PanelImportFilme.BeobPfad", ex);
+                        Log.fehlerMeldung(733025319, "PanelImportFilme.BeobPfad", ex);
                     }
                 }
             }
@@ -460,7 +506,7 @@ public class PanelFilmlisteLaden extends PanelVorlage {
         }
 
         private void tus() {
-            Daten.system[Konstanten.SYSTEM_IMPORT_URL_MANUELL_NR] = jTextFieldUrl.getText();
+            Daten.mVConfig.add(MVConfig.SYSTEM_IMPORT_URL_MANUELL, jTextFieldUrl.getText());
         }
     }
 }
