@@ -19,8 +19,9 @@
  */
 package mediathek.gui.dialogEinstellungen;
 
+import com.jidesoft.utils.SystemInfo;
 import java.awt.Color;
-import java.awt.Component;
+import java.awt.Dimension;
 import java.awt.FileDialog;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
@@ -31,6 +32,7 @@ import java.io.File;
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.JButton;
 import javax.swing.JFileChooser;
+import javax.swing.JFrame;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JTextField;
@@ -38,10 +40,8 @@ import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
-
-import com.jidesoft.utils.SystemInfo;
-import java.awt.Dimension;
-import mediathek.daten.DDaten;
+import mediathek.controller.Log;
+import mediathek.daten.Daten;
 import mediathek.daten.DatenProg;
 import mediathek.daten.DatenPset;
 import mediathek.daten.ListePset;
@@ -49,7 +49,6 @@ import mediathek.gui.PanelVorlage;
 import mediathek.res.GetIcon;
 import mediathek.tool.GuiFunktionen;
 import mediathek.tool.ListenerMediathekView;
-import mediathek.tool.Log;
 
 public class PanelPsetKurz extends PanelVorlage {
 
@@ -58,10 +57,10 @@ public class PanelPsetKurz extends PanelVorlage {
     private DatenPset pSet = null;
     private ListePset listePset;
 
-    public PanelPsetKurz(DDaten d, Component parentComponent, ListePset llistePset) {
+    public PanelPsetKurz(Daten d, JFrame parentComponent, ListePset llistePset) {
         super(d, parentComponent);
         initComponents();
-        jButtonZiel.setIcon(GetIcon.getIcon("fileopen_16.png"));
+        jButtonZiel.setIcon(GetIcon.getProgramIcon("fileopen_16.png"));
         listePset = llistePset;
         jListPset.setModel(new DefaultComboBoxModel<String>(listePset.getObjectDataCombo()));
         if (listePset.size() > 0) {
@@ -192,7 +191,7 @@ public class PanelPsetKurz extends PanelVorlage {
         c.gridx = 2;
         c.weightx = 0;
         JButton button = new JButton();
-        button.setIcon(GetIcon.getIcon("fileopen_16.png"));
+        button.setIcon(GetIcon.getProgramIcon("fileopen_16.png"));
         button.addActionListener(new ZielBeobachter(textField, arr, idx));
         gridbag.setConstraints(button, c);
         panel.add(button);
@@ -269,7 +268,7 @@ public class PanelPsetKurz extends PanelVorlage {
 
         jLabel2.setText("Zielpfad:");
 
-        jButtonZiel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/fileopen_16.png"))); // NOI18N
+        jButtonZiel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/mediathek/res/programm/fileopen_16.png"))); // NOI18N
 
         jScrollPane2.setBorder(javax.swing.BorderFactory.createLineBorder(javax.swing.UIManager.getDefaults().getColor("TextField.selectionBackground")));
 
@@ -363,17 +362,20 @@ public class PanelPsetKurz extends PanelVorlage {
         JTextField textField;
         String[] arr = null;
         int idx;
+        boolean file;
 
         public ZielBeobachter(JTextField tt, String[] aarr, int iidx) {
             textField = tt;
             arr = aarr; // Programmarray
             idx = iidx;
+            file = true;
         }
 
         public ZielBeobachter(JTextField tt, int iidx) {
             // für den Zielpfad
             textField = tt;
             idx = iidx;
+            file = false;
         }
 
         @Override
@@ -384,8 +386,10 @@ public class PanelPsetKurz extends PanelVorlage {
             //we can use native directory chooser on Mac...
             if (SystemInfo.isMacOSX()) {
                 //we want to select a directory only, so temporarily change properties
-                System.setProperty("apple.awt.fileDialogForDirectories", "true");
-                FileDialog chooser = new FileDialog(ddaten.mediathekGui, "Film speichern");
+                if (!file) {
+                    System.setProperty("apple.awt.fileDialogForDirectories", "true");
+                }
+                FileDialog chooser = new FileDialog(daten.mediathekGui, "Film speichern");
                 chooser.setVisible(true);
                 if (chooser.getFile() != null) {
                     //A directory was selected, that means Cancel was not pressed
@@ -397,16 +401,18 @@ public class PanelPsetKurz extends PanelVorlage {
                             arr[idx] = textField.getText();
                         }
                     } catch (Exception ex) {
-                        Log.fehlerMeldung(392847589, Log.FEHLER_ART_PROG, "DialogZielPset.ZielBeobachter", ex);
+                        Log.fehlerMeldung(392847589,  "DialogZielPset.ZielBeobachter", ex);
                     }
                 }
-                System.setProperty("apple.awt.fileDialogForDirectories", "false");
+                if (!file) {
+                    System.setProperty("apple.awt.fileDialogForDirectories", "false");
+                }
             } else {
                 //use the cross-platform swing chooser
                 int returnVal;
                 JFileChooser chooser = new JFileChooser();
                 chooser.setCurrentDirectory(new File(textField.getText()));
-                chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
+                chooser.setFileSelectionMode(file ? JFileChooser.FILES_ONLY : JFileChooser.DIRECTORIES_ONLY);
                 returnVal = chooser.showOpenDialog(null);
                 if (returnVal == JFileChooser.APPROVE_OPTION) {
                     try {
@@ -417,7 +423,7 @@ public class PanelPsetKurz extends PanelVorlage {
                             arr[idx] = textField.getText();
                         }
                     } catch (Exception ex) {
-                        Log.fehlerMeldung(613986500, Log.FEHLER_ART_PROG, "DialogZielPset.ZielBeobachter", ex);
+                        Log.fehlerMeldung(613986500,  "DialogZielPset.ZielBeobachter", ex);
                     }
                 }
             }
