@@ -31,18 +31,18 @@ import java.util.Enumeration;
 import java.util.Iterator;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipFile;
+import javax.swing.JFrame;
 import javax.swing.JOptionPane;
-import mediathek.controller.io.starter.RuntimeExec;
-import mediathek.daten.DDaten;
+import mediathek.controller.starter.RuntimeExec;
 import mediathek.daten.Daten;
 import mediathek.daten.DatenProg;
 import mediathek.daten.DatenPset;
 import mediathek.daten.ListePset;
-import mediathek.gui.PanelVorlage;
 import mediathek.gui.dialog.DialogHilfe;
 import mediathek.gui.dialog.DialogOk;
 import mediathek.gui.dialogEinstellungen.DialogImportPset;
 import mediathek.gui.dialogEinstellungen.PanelProgrammPfade;
+import msearch.tool.MSConst;
 
 public class GuiFunktionenProgramme extends GuiFunktionen {
 
@@ -55,15 +55,13 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
         final String PFAD_WIN = "\\SMPlayer\\mplayer\\mplayer.exe";
         String pfad;
         switch (getOs()) {
-            case OS_LINUX:
+            case LINUX:
                 pfad = PFAD_LINUX;
                 break;
-            case OS_MAC:
+            case MAC:
                 pfad = PFAD_MAC;
                 break;
-            case OS_WIN_32BIT:
-            case OS_WIN_64BIT:
-            case OS_UNKNOWN:
+
             default:
                 if (System.getenv("ProgramFiles") != null) {
                     pfad = System.getenv("ProgramFiles") + PFAD_WIN;
@@ -88,15 +86,13 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
         final String PFAD_WIN = "\\VideoLAN\\VLC\\vlc.exe";
         String pfad;
         switch (getOs()) {
-            case OS_LINUX:
+            case LINUX:
                 pfad = PFAD_LINUX_VLC;
                 break;
-            case OS_MAC:
+            case MAC:
                 pfad = PFAD_MAC_VLC;
                 break;
-            case OS_WIN_32BIT:
-            case OS_WIN_64BIT:
-            case OS_UNKNOWN:
+
             default:
                 pfad = PFAD_WIN_DEFAULT;
                 if (new File(pfad).exists()) {
@@ -130,15 +126,13 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
         final String PFAD_WINDOWS_FLV = "bin\\flvstreamer_win32_latest.exe";
         String pfad;
         switch (getOs()) {
-            case OS_LINUX:
+            case LINUX:
                 pfad = PFAD_LINUX_FLV;
                 break;
-            case OS_MAC:
+            case MAC:
                 pfad = Funktionen.getPathJar() + PFAD_MAC_FLV;
                 break;
-            case OS_WIN_32BIT:
-            case OS_WIN_64BIT:
-            case OS_UNKNOWN:
+
             default:
                 pfad = Funktionen.getPathJar() + PFAD_WINDOWS_FLV;
         }
@@ -149,6 +143,33 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
         }
     }
 
+    public static String getMusterPfadFFmpeg() {
+        // liefert den Standardpfad für das entsprechende BS 
+        // bei Win+Mac wird das Programm mitgeliefert und liegt 
+        // im Ordner "bin" der mit dem Programm mitgeliefert wird
+        // bei Linux muss das Programm auf dem Rechner installiert sein
+        final String PFAD_LINUX_FFMPEG = "/usr/bin/ffmpeg";
+        final String PFAD_MAC_FFMPEG = "bin/ffmpeg";
+        final String PFAD_WINDOWS_FFMPEG = "bin\\ffmpeg.exe";
+        String pfad;
+        switch (getOs()) {
+            case LINUX:
+                pfad = PFAD_LINUX_FFMPEG;
+                break;
+            case MAC:
+                pfad = Funktionen.getPathJar() + PFAD_MAC_FFMPEG;
+                break;
+
+            default:
+                pfad = Funktionen.getPathJar() + PFAD_WINDOWS_FFMPEG;
+        }
+        if (new File(pfad).exists()) {
+            return pfad;
+        } else {
+            return "";
+        }
+    }
+
     public static String getPfadScript() {
         // liefert den Standardpfad zum Script "Ansehen" für das entsprechende BS 
         // liegt im Ordner "bin" der mit dem Programm mitgeliefert wird
@@ -156,74 +177,100 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
         final String PFAD_LINUX_SCRIPT = "bin/flv.sh";
         final String PFAD_WINDOWS_SCRIPT = "bin\\flv.bat";
         switch (getOs()) {
-            case OS_LINUX:
+            case LINUX:
                 pfadScript = getPathJar() + PFAD_LINUX_SCRIPT;
                 break;
-            case OS_MAC:
+            case MAC:
                 pfadScript = getPathJar() + PFAD_LINUX_SCRIPT;
                 break;
-            case OS_WIN_32BIT:
-            case OS_WIN_64BIT:
-            case OS_UNKNOWN:
+
             default:
                 pfadScript = getPathJar() + PFAD_WINDOWS_SCRIPT;
         }
         return pfadScript;
     }
 
-    public static String getPfadMplayer(DDaten dd) {
+    public static String getPfadMplayer(JFrame parent, Daten dd) {
         // liefert den Pfad wenn vorhanden, wenn nicht wird er in einem Dialog abgefragt
-        if (Daten.system[Konstanten.SYSTEM_PFAD_MPLAYER_NR].equals("")) {
-            new DialogOk(null, true, new PanelProgrammPfade(dd, false /* vlc */, false /* flvstreamer */, true /* mplayer */), "Pfade Standardprogramme").setVisible(true);
+        if (Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_MPLAYER).equals("")) {
+            new DialogOk(null, true, new PanelProgrammPfade(parent, dd, false /* vlc */, false /* flvstreamer */, true /* mplayer */, false/*ffmpeg*/), "Pfade Standardprogramme").setVisible(true);
         }
-        return Daten.system[Konstanten.SYSTEM_PFAD_MPLAYER_NR];
+        return Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_MPLAYER);
     }
 
-    public static String getPfadVlc(DDaten dd) {
+    public static String getPfadVlc(JFrame parent, Daten dd) {
         // liefert den Pfad wenn vorhanden, wenn nicht wird er in einem Dialog abgefragt
-        if (Daten.system[Konstanten.SYSTEM_PFAD_VLC_NR].equals("")) {
-            new DialogOk(null, true, new PanelProgrammPfade(dd, true /* vlc */, false /* flvstreamer */, false /* mplayer */), "Pfade Standardprogramme").setVisible(true);
+        if (Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_VLC).equals("")) {
+            new DialogOk(null, true, new PanelProgrammPfade(parent, dd, true /* vlc */, false /* flvstreamer */, false /* mplayer */, false/*ffmpeg*/), "Pfade Standardprogramme").setVisible(true);
         }
-        return Daten.system[Konstanten.SYSTEM_PFAD_VLC_NR];
+        return Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_VLC);
     }
 
-    public static String getPfadFlv(DDaten dd) {
+    public static String getPfadFlv(JFrame parent, Daten dd) {
         // liefert den Pfad wenn vorhanden, wenn nicht wird er in einem Dialog abgefragt
-        if (Daten.system[Konstanten.SYSTEM_PFAD_FLVSTREAMER_NR].equals("")) {
-            new DialogOk(null, true, new PanelProgrammPfade(dd, false /* vlc */, true /* flvstreamer */, false /* mplayer */), "Pfade Standardprogramme").setVisible(true);
+        if (Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_FLVSTREAMER).equals("")) {
+            new DialogOk(null, true, new PanelProgrammPfade(parent, dd, false /* vlc */, true /* flvstreamer */, false /* mplayer */, false/*ffmpeg*/), "Pfade Standardprogramme").setVisible(true);
         }
-        return Daten.system[Konstanten.SYSTEM_PFAD_FLVSTREAMER_NR];
+        return Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_FLVSTREAMER);
     }
 
-    public static boolean addVorlagen(PanelVorlage parent, DDaten ddaten, ListePset pSet, boolean auto) {
-        // Standardgruppen laden
-        if (pSet != null) {
-            parent.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-            for (DatenPset ps : pSet) {
-                if (!ps.arr[DatenPset.PROGRAMMSET_ADD_ON_NR].equals("")) {
-                    if (!addOnZip(ps.arr[DatenPset.PROGRAMMSET_ADD_ON_NR])) {
-                        // und Tschüss
-                        return false;
-                    }
-                }
-            }
-            parent.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
+    public static String getPfadFFmpeg(JFrame parent, Daten dd) {
+        // liefert den Pfad wenn vorhanden, wenn nicht wird er in einem Dialog abgefragt
+        if (Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_FFMPEG).equals("")) {
+            new DialogOk(null, true, new PanelProgrammPfade(parent, dd, false /* vlc */, false /* flvstreamer */, false /* mplayer */, true /*ffmpeg*/), "Pfade Standardprogramme").setVisible(true);
+        }
+        return Daten.mVConfig.get(MVConfig.SYSTEM_PFAD_FFMPEG);
+    }
+
+    public static void addSetVorlagen(JFrame parent, Daten daten, ListePset pSet, boolean auto, boolean setVersion) {
+        if (pSet == null) {
             if (!auto) {
-                DialogImportPset dialog = new DialogImportPset(null, true, ddaten, pSet);
-                dialog.setVisible(true);
-                if (!dialog.ok) {
-                    return false;
+                MVMessageDialog.showMessageDialog(null, "Die Datei wurde nicht importiert!",
+                        "Fehler", JOptionPane.ERROR_MESSAGE);
+            }
+            return;
+        }
+        if (parent != null) {
+            parent.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
+        }
+        for (DatenPset ps : pSet) {
+            if (!ps.arr[DatenPset.PROGRAMMSET_ADD_ON_NR].equals("")) {
+                if (!addOnZip(ps.arr[DatenPset.PROGRAMMSET_ADD_ON_NR])) {
+                    // und Tschüss
+                    if (!auto) {
+                        MVMessageDialog.showMessageDialog(null, "Die Datei wurde nicht importiert!",
+                                "Fehler", JOptionPane.ERROR_MESSAGE);
+                    }
+                    return;
                 }
             }
-            if (ddaten.listePset.addPset(pSet)) {
-                MVMessageDialog.showMessageDialog(null, pSet.size() + " Programmset importiert!",
-                        "Ok", JOptionPane.INFORMATION_MESSAGE);
+        }
+        if (parent != null) {
+            parent.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
+        }
+        if (auto) {
+            if (Daten.listePset.addPset(pSet)) {
+                if (setVersion) {
+                    Daten.mVConfig.add(MVConfig.SYSTEM_VERSION_PROGRAMMSET, pSet.version);
+                }
             }
-            return true;
         } else {
-            MVMessageDialog.showMessageDialog(null, "Die Datei wurde nicht importiert!",
-                    "Fehler", JOptionPane.ERROR_MESSAGE);
-            return false;
+            DialogImportPset dialog = new DialogImportPset(parent, true, daten, pSet);
+            dialog.setVisible(true);
+            if (dialog.ok) {
+                if (Daten.listePset.addPset(pSet)) {
+                    if (setVersion) {
+                        Daten.mVConfig.add(MVConfig.SYSTEM_VERSION_PROGRAMMSET, pSet.version);
+                    }
+                    MVMessageDialog.showMessageDialog(null, pSet.size() + " Programmset importiert!",
+                            "Ok", JOptionPane.INFORMATION_MESSAGE);
+
+                } else {
+                    MVMessageDialog.showMessageDialog(null, "Die Datei wurde nicht importiert!",
+                            "Fehler", JOptionPane.ERROR_MESSAGE);
+
+                }
+            }
         }
     }
 
@@ -240,7 +287,7 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
                     // und Tschüss
                     return false;
                 }
-                if (datei.endsWith(GuiKonstanten.FORMAT_ZIP)) {
+                if (datei.endsWith(MSConst.FORMAT_ZIP)) {
                     if (!entpacken(zipFile, new File(zielPfad))) {
                         // und Tschüss
                         return false;
@@ -260,7 +307,7 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
                 conn.setConnectTimeout(timeout);
                 conn.setReadTimeout(timeout);
                 conn.setRequestProperty("User-Agent", Daten.getUserAgent());
-                if (datei.endsWith(GuiKonstanten.FORMAT_ZIP)) {
+                if (datei.endsWith(MSConst.FORMAT_ZIP)) {
 
                     File tmpFile = File.createTempFile("mediathek", null);
                     tmpFile.deleteOnExit();
@@ -288,7 +335,7 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
                     in.close();
                 }
             }
-        } catch (Exception ex) {
+        } catch (Exception ignored) {
         }
         return true;
     }
@@ -335,7 +382,6 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
 
     private static File buildDirectoryHierarchyFor(String entryName, File destDir) {
         int lastIndex = entryName.lastIndexOf('/');
-        String entryFileName = entryName.substring(lastIndex + 1);
         String internalPathToEntry = entryName.substring(0, lastIndex + 1);
         return new File(destDir, internalPathToEntry);
     }
@@ -390,19 +436,19 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
                     ret = true;
                 }
             }
-        } catch (Exception ex) {
+        } catch (Exception ignored) {
         }
         return ret;
     }
 
-    public static boolean programmePruefen(DDaten daten) {
+    public static boolean programmePruefen(JFrame jFrame, Daten daten) {
         // prüfen ob die eingestellten Programmsets passen
         final String PIPE = "| ";
         final String LEER = "      ";
         final String PFEIL = " -> ";
         boolean ret = true;
         String text = "";
-        Iterator<DatenPset> itPset = daten.listePset.iterator();
+        Iterator<DatenPset> itPset = Daten.listePset.iterator();
         DatenPset datenPset;
         DatenProg datenProg;
         while (itPset.hasNext()) {
@@ -459,7 +505,7 @@ public class GuiFunktionenProgramme extends GuiFunktionen {
                 text += "++++++++++++++++++++++++++++++++++++++++++++" + "\n\n\n";
             }
         }
-        new DialogHilfe(null, true, text).setVisible(true);
+        new DialogHilfe(jFrame, true, text).setVisible(true);
         return ret;
     }
 }
